@@ -1,12 +1,22 @@
 /****************************************************************************
 **
 ** Copyright (C) 2016 The Qt Company Ltd.
-** Contact: http://www.qt.io/licensing/
+** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of the examples of the Qt Toolkit.
 **
 ** $QT_BEGIN_LICENSE:BSD$
-** You may use this file under the terms of the BSD license as follows:
+** Commercial License Usage
+** Licensees holding valid commercial Qt licenses may use this file in
+** accordance with the commercial license agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and The Qt Company. For licensing terms
+** and conditions see https://www.qt.io/terms-conditions. For further
+** information use the contact form at https://www.qt.io/contact-us.
+**
+** BSD License Usage
+** Alternatively, you may use this file under the terms of the BSD license
+** as follows:
 **
 ** "Redistribution and use in source and binary forms, with or without
 ** modification, are permitted provided that the following conditions are
@@ -52,15 +62,21 @@
 
 WebView::WebView(QWidget *parent)
     : QWebEngineView(parent)
-    , m_loadProgress(0)
+    , m_loadProgress(100)
 {
+    connect(this, &QWebEngineView::loadStarted, [this]() {
+        m_loadProgress = 0;
+        emit favIconChanged(favIcon());
+    });
     connect(this, &QWebEngineView::loadProgress, [this](int progress) {
         m_loadProgress = progress;
     });
     connect(this, &QWebEngineView::loadFinished, [this](bool success) {
-        if (!success) {
-            m_loadProgress = 0;
-        }
+        m_loadProgress = success ? 100 : -1;
+        emit favIconChanged(favIcon());
+    });
+    connect(this, &QWebEngineView::iconChanged, [this](const QIcon &) {
+        emit favIconChanged(favIcon());
     });
 
     connect(this, &QWebEngineView::renderProcessTerminated,
@@ -115,21 +131,39 @@ bool WebView::isWebActionEnabled(QWebEnginePage::WebAction webAction) const
     return page()->action(webAction)->isEnabled();
 }
 
+QIcon WebView::favIcon() const
+{
+    QIcon favIcon = icon();
+    if (!favIcon.isNull())
+        return favIcon;
+
+    if (m_loadProgress < 0) {
+        static QIcon errorIcon(QStringLiteral(":dialog-error.png"));
+        return errorIcon;
+    } else if (m_loadProgress < 100) {
+        static QIcon loadingIcon(QStringLiteral(":view-refresh.png"));
+        return loadingIcon;
+    } else {
+        static QIcon defaultIcon(QStringLiteral(":text-html.png"));
+        return defaultIcon;
+    }
+}
+
 QWebEngineView *WebView::createWindow(QWebEnginePage::WebWindowType type)
 {
+    BrowserWindow *mainWindow = qobject_cast<BrowserWindow*>(window());
+    if (!mainWindow)
+        return nullptr;
+
     switch (type) {
     case QWebEnginePage::WebBrowserTab: {
-        BrowserWindow *mainWindow = qobject_cast<BrowserWindow*>(window());
         return mainWindow->tabWidget()->createTab();
     }
     case QWebEnginePage::WebBrowserBackgroundTab: {
-        BrowserWindow *mainWindow = qobject_cast<BrowserWindow*>(window());
-        return mainWindow->tabWidget()->createTab(false);
+        return mainWindow->tabWidget()->createBackgroundTab();
     }
     case QWebEnginePage::WebBrowserWindow: {
-        BrowserWindow *mainWindow = new BrowserWindow();
-        Browser::instance().addWindow(mainWindow);
-        return mainWindow->currentTab();
+        return mainWindow->browser()->createWindow()->currentTab();
     }
     case QWebEnginePage::WebDialog: {
         WebPopupWindow *popup = new WebPopupWindow(page()->profile());
@@ -151,7 +185,6 @@ void WebView::contextMenuEvent(QContextMenuEvent *event)
         menu->insertAction(before, page()->action(QWebEnginePage::OpenLinkInNewWindow));
         menu->insertAction(before, page()->action(QWebEnginePage::OpenLinkInNewTab));
     }
-    connect(menu, &QMenu::aboutToHide, menu, &QObject::deleteLater);
     menu->popup(event->globalPos());
 }
 
